%  modelit.ui.Slider - A slider is a component that lets the user graphically select a value by sliding a knob within a bounded interval.   
%  The slider can show major tick marks, minor tick marks and labels between them.   
%  Users move the bar by pressing the mouse button and dragging the pointer over the bar, or by clicking in the trough.   
%  By releasing the mouse button a callback is triggered. The location of the bar indicates a numeric value.   
%  Specifies the next component to get the focus after this one, for example, when the tab key or shift-tab key is used.   
%   
%  modelit.ui.Slider Properties:   
%    Style                  - Slider (Read only)   
%    NextFocusableComponent - Specifies the next component to get the focus after this one.   
%    ContextMenu            - The handle of the context menu associated with the slider.   
%    CMenu                  - The handle of the context menu associated with the slider.   
%    Callback               - Specifies the function that should be executed when the user moves the slider.   
%    Value                  - The slider's current value.   
%    ForegroundColor        - The color of the slider.   
%    BackgroundColor        - The background color of the slider.   
%    TooltipString          - The TooltipString property specifies the text of the tooltip associated with the slider.   
%    Minimum                - The slider's minimum allowed value.   
%    Maximum                - The slider's maximum allowed value.   
%    MajorTickSpacing       - Represents the distance, measured in values, between each major tick mark.   
%    MinorTickSpacing       - Represents the distance, measured in values, between each minor tick mark.   
%    Orientation            - The slider's orientation.   
%    SnapToTicks            - Determines whether the slider knob (and the data value it represents) resolves to the closest tick mark next to where the user positioned it.   
%    PaintLabels            - Determines whether labels are painted on the slider.   
%    PaintTicks             - Determines whether tick marks are painted on the slider.   
%    Labels                 - The first column is the value, the second column the corresponding   
%    MatlabHandle           - The handle of the associated Matlab container for this java object.   
%    JavaHandle             - The underlying java object.   
%    Interruptible          - Callback routine interruption.   
%    BusyAction             - Callback queuing.   
%    Position               - Size and location of the component.   
%    Tag                    - User specified object identifier.   
%    Userdata               - User specified data for this modelit.ui.Jacontrol object   
%    Units                  - Used to interpret the extent and position properties.   
%    Visible                - Component visibility.   
%    Enable                 - Disable or enable the component.   
%    Extent                 - Position rectangle (read only).   
%    Clipping               - Clipping mode.   
%    Type                   - String with the object type.   
%    FontUnits              - This property determines the units used by the FontSize property.   
%    FontWeight             - Setting this property to bold selects a bold version of the component's font, when it is available on your system.   
%    FontSize               - A number specifying the size in pixels of the component's font.   
%    FontName               - The name of the font in which to display the text in the components.   
%    FontAngle              - Setting this property to italic selects a slanted version of the component's font, when it is available on your system.   
%    MouseEnteredCallback   - Specifies the callback function that should be executed when the mouse enters the component.   
%    MouseExitedCallback    - Specifies the callback function that should be executed when the mouse exits the component.   
%    MouseClickedCallback   - Specifies the function that should be executed when the mouse is clicked on the component   
%    PreferredSize          - The component's preferred size, measured in pixels.   
%    MinimumSize            - The component's minimum size, measured in pixels.   
%    MaximumSize            - The component's maximum size, measured in pixels.   
%    Parent                 - The component's parent.   
%    Children               - The component's children.   
%   
%  modelit.ui.Slider Methods:   
%    cleanup                 - Reset object fields to empty values, called by the destructor.   
%    Slider                  - modelit.ui.Slider constructor.   
%    delete                  - modelit.ui.Jacontrol destructor.   
%    isappdata               - True if application defined data exists.   
%    getappdata              - Get application defined data.   
%    setappdata              - Set application defined data.   
%    ishandle                - Returns true if this is a valid graphics object   
%    java                    - Returns the underlying Java object   
%    handle                  - Returns the handle of the component's Matlab container   
%    ancestor                - Returns the handle of the closest ancestor of obj   
%    browse                  - (Static) Browse the available classes in the modelit.ui package   
%    getDefaultScalarElement - (Static) Create a default object for heterogeneous arrays.   
%    ne                      - Not equal relation for handles.   
%    eq                      - Equal relation for handles.   
%    findobj                 - Returns the objects whose property values match those passed as param-value pairs to the findobj command.   
%    set                     - Set object properties   
%    get                     - GET    Get MATLAB object properties.   
%    setdisp                 - SETDISP    Specialized MATLAB object property display.   
%    getdisp                 - GETDISP    Specialized MATLAB object property display.   
   
   
% © Modelit 2006-2023   
% Matlab release: 2021a   
% Date: 2023/03/30 18:46:31   
