%  modelit.ui.TreeTable - A treetable for display of hierarchical data.   
%  Furthermore the table has some built in features to render icons, dates, comboboxes,   
%  Change color of foreground and background of the table cells etc.   
%   
%  modelit.ui.TreeTable Properties:   
%    Style                  - TreeTable (Read only)   
%    ColumnClass            - (Read only) CellString with class per column.   
%    NextFocusableComponent - Specifies the next component to get the focus after this one.   
%    Hierarchy              - This array defines the tree structure   
%    ShowCheckboxes         - If true, show checkbox in the hierarchical column of the treetable.   
%    CheckedRows            - If true, check the checkbox for this row.   
%    RowCheckedCallback     - Function that executes when the user clicks on the checkboxes in the tree   
%    CellToolTips           - Set the tooltips for the treetable cells.   
%    Anchor                 - Returns the index (row and column) of the first selected cell in the current selection.   
%    BackgroundColor        - The background color of the treetable.   
%    GridBackgroundColor    - The background color of the treetable.   
%    Border                 - Indicates if a border is shown around the treetable's scrollpane.   
%    Busy                   - If true a indeterminate progress indicator appears on the faded treetable.   
%    CellBackgroundColor    - Specifies an index in the ColorSet for every treetable cell.   
%    CellForegroundColor    - Specifies an index in the ColorSet for every treetable cell.   
%    CellSelection          - Indicates whether the user can select single cells (true) or only rows (false) in the treetable.   
%    ColorSet               - First column is a key   
%    ColumnControl          - The Column Control is an icon that renders to the right of the column headers,   
%    ColumnControlVisible   - The Column Control is an icon that renders to the right of the column headers,   
%    ColumnEditable         - Specifies the columns which are editable.   
%    ColumnFormats          - Set the format of the treetable's columns.   
%    ColumnNames            - Set the names (headers) of the treetable columns.   
%    IconNames              - The cellcontent specifies the icon (from the iconset) to be shown   
%    ColumnTooltips         - Set the tooltips for the treetable columns.   
%    ColumnWidths           - Set the widths of the treetable's columns, -1 if auto.   
%    ContextMenu            - The handle of the context menu associated with the treetable.   
%    CMenu                  - The handle of the context menu associated with the treetable.   
%    ControlButtonMenu      - The handle of the menu associated with the treetable's columncontrol button in the right upper corner of the treetable.   
%    Data                   - Data for the treetable, every column should have the same format e.g. all strings or numbers.   
%    ExpandedRows           - Expansion state of every row in the treetable   
%    Content                - ?   
%    DragEnabled            - Specifies if the content of the selected cells/rows/columns can be   
%    EditCallback           - Function that should be executed when the user changes the value of a cell in the treetable.   
%    ForegroundColor        - The foreground color of the treetable (font color).   
%    Grid                   - Specifies whether the treetable draws horizontal lines, vertical lines, both or nothing between the treetable cells.   
%    GridColor              - The color of the treetable's (partial) grid when visible.   
%    HeaderBackgroundColor  - The background color of the treetable header.   
%    HeaderFontAngle        - Setting this property to italic selects a slanted version of the treetable header's font.   
%    HeaderFontName         - The name of the font in which to display the string in the treetable header.   
%    HeaderFontSize         - A number specifying the size in pixels of the treetable header's font.   
%    HeaderFontWeight       - Setting this property to bold selects a bold version of the treetable header's font.   
%    HeaderForegroundColor  - The foreground color of the treetable (text color) .   
%    HeaderVisible          - Display a header with columnnames above the treetable.   
%    Highlighter            - Rows can be highlighted to make it easier to distinguish between different rows by using a subtle background color scheme for every other row.   
%    Iconset                - The name of the jar file with icons or the full path to the jar file.   
%    InfoLabel              - Specifies if a label with info is visible in the lower right   
%    InfoLabelFontAngle     - Setting this property to italic selects a slanted version of the info label's font, when it is available on your system.   
%    InfoLabelFontName      - The name of the font in which to display the string in the info label.   
%    InfoLabelFontSize      - A number specifying the size in pixels of the info label's font.   
%    InfoLabelFontWeight    - Setting this property to bold selects a bold version of the infor label's font, when it is available on your system.   
%    KeyPressedCallback     - Function that should be executed when the user presses a key or combination of keys.   
%    Prompt                 - The prompt text (shown empty hint) for the treetable   
%    Scrollbar              - Normally a treetable in a scrollPane will fit all columns within the scrollpane's viewport,   
%    SelectedColumns        - A vector of indices corresponding to the currently selected treetable columns.   
%    SelectedRows           - A vector of indices corresponding to the currently selected treetable rows.   
%    Value                  - A a vector of indices corresponding to the currently selected treetable rows.   
%    SelectionCallback      - Function that should be executed when the user changes the current selection.   
%    Callback               - Function that should be executed when the user changes the current selection.   
%    SelectionMode          - The selection mode. The following selectionMode values are allowed:   
%    ShowRoot               - If true show root of treetable   
%    MatlabHandle           - The handle of the associated Matlab container for this java object.   
%    JavaHandle             - The underlying java object.   
%    Interruptible          - Callback routine interruption.   
%    BusyAction             - Callback queuing.   
%    Position               - Size and location of the component.   
%    Tag                    - User specified object identifier.   
%    Userdata               - User specified data for this modelit.ui.Jacontrol object   
%    Units                  - Used to interpret the extent and position properties.   
%    Visible                - Component visibility.   
%    Enable                 - Disable or enable the component.   
%    Extent                 - Position rectangle (read only).   
%    Clipping               - Clipping mode.   
%    Type                   - String with the object type.   
%    FontUnits              - This property determines the units used by the FontSize property.   
%    FontWeight             - Setting this property to bold selects a bold version of the component's font, when it is available on your system.   
%    FontSize               - A number specifying the size in pixels of the component's font.   
%    FontName               - The name of the font in which to display the text in the components.   
%    FontAngle              - Setting this property to italic selects a slanted version of the component's font, when it is available on your system.   
%    MouseEnteredCallback   - Specifies the callback function that should be executed when the mouse enters the component.   
%    MouseExitedCallback    - Specifies the callback function that should be executed when the mouse exits the component.   
%    MouseClickedCallback   - Specifies the function that should be executed when the mouse is clicked on the component   
%    PreferredSize          - The component's preferred size, measured in pixels.   
%    MinimumSize            - The component's minimum size, measured in pixels.   
%    MaximumSize            - The component's maximum size, measured in pixels.   
%    Parent                 - The component's parent.   
%    Children               - The component's children.   
%   
%  modelit.ui.TreeTable Methods:   
%    cleanup                 - Reset object fields to empty values, called by the destructor.   
%    TreeTable               - modelit.ui.TreeTable constructor   
%    expandAll               - Expand or collapse entire tree   
%    setValueAt              - Programmatically set a value in the table.   
%    getValueAt              - Get a value in the table.   
%    delete                  - modelit.ui.Jacontrol destructor.   
%    isappdata               - True if application defined data exists.   
%    getappdata              - Get application defined data.   
%    setappdata              - Set application defined data.   
%    ishandle                - Returns true if this is a valid graphics object   
%    java                    - Returns the underlying Java object   
%    handle                  - Returns the handle of the component's Matlab container   
%    ancestor                - Returns the handle of the closest ancestor of obj   
%    browse                  - (Static) Browse the available classes in the modelit.ui package   
%    getDefaultScalarElement - (Static) Create a default object for heterogeneous arrays.   
%    ne                      - Not equal relation for handles.   
%    eq                      - Equal relation for handles.   
%    findobj                 - Returns the objects whose property values match those passed as param-value pairs to the findobj command.   
%    set                     - Set object properties   
%    get                     - GET    Get MATLAB object properties.   
%    setdisp                 - SETDISP    Specialized MATLAB object property display.   
%    getdisp                 - GETDISP    Specialized MATLAB object property display.   
   
   
% © Modelit 2006-2023   
% Matlab release: 2021a   
% Date: 2023/03/30 18:46:31   
